==> HostCMS.Free_6.7.tar.gz: modules/tag/i18n/en.php <==
<?php
/**
 * Tags.
 *
 * @package HostCMS
 * @subpackage Tag
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Tags',
	'menu' => 'Tags',
	'main_form_caption_h1' => 'Tags',
	'title' => 'Tags',
	'main_menu' => 'Tag',
	'menu_add' => 'Add',
	'markDeleted_success' => 'Tag deleted successfully!',
	'form_edit_add_title_add' => 'Add tag',
	'form_edit_add_title_edit' => 'Edit tag',
	'id' => 'Id',
	'name' => '<acronym title="Label name">Tag name</acronym>',
	'add_tag_name' => '<acronym title="Label name. You can set several tags. Each tag should be added from a new line">Name of tag or tags</acronym>',
	'path' => '<acronym title="Label name in URL, e.g. Disky communication">Tag name in URL</acronym>',
	'show_invalid_characters_path' => 'Invalid characters specified (permissible characters range: a-z, A-Z, 0-9, "_", "-" and ".")',
	'description' => '<acronym title="Label description">Tag description</acronym>',
	'form_add_tag_or_tags_description' => '<acronym title="Label or labels description">Description of tag or tags</acronym>',
	'edit_success' => 'Tag information edited successfully!',
	'error_join_some_tags' => 'Unable to combine tags due to an access rights error. Tags %s cannot be combined under the actual user.',
	'move_tags_groups_title' => 'Transfer of tag groups and tags',
	'move_tags_groups_id' => "<acronym title=\"Group into which tags and tag groups will be transferred.\">Parent group</acronym>",
	'move_tags_groups_form_button_name' => 'Transfer',
	'move_success' => 'Tags have been transferred.',
	'merge_success' => 'Tags have been merged.',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'seo_title' => '<acronym title="Meta element title">Title</acronym>',
	'seo_description' => '<acronym title="Meta element description">Description</acronym>',
	'seo_keywords' => '<acronym title="Meta element keywords">Keywords</acronym>',
);

==> HostCMS.Free_7.0.tar.gz: modules/tag/i18n/en.php <==
<?php

return array(
	'model_name' => 'Tags',
	'menu' => 'Tags',
	'main_form_caption_h1' => 'Tags',
	'title' => 'Tags',
	'main_menu' => 'Tag',
	'menu_add' => 'Add',
	'markDeleted_success' => 'Tag deleted successfully!',
	'form_edit_add_title_add' => 'Add tag',
	'form_edit_add_title_edit' => 'Edit tag',
	'id' => 'ID',
	'name' => 'Tag name',
	'add_tag_name' => '<acronym title="Label name. You can set several tags. Each tag should be added from a new line">Name of tag or tags</acronym>',
	'path' => '<acronym title="Label name in URL, e.g. Disky communication">Tag name in URL</acronym>',
	'show_invalid_characters_path' => 'Invalid characters specified (permissible characters range: a-z, A-Z, 0-9, "_", "-" and ".")',
	'description' => '<acronym title="Label description">Tag description</acronym>',
	'form_add_tag_or_tags_description' => 'Description of tag or tags',
	'edit_success' => 'Tag information edited successfully!',
	'error_join_some_tags' => 'Unable to combine tags due to an access rights error. Tags %s cannot be combined under the actual user.',
	'move_tags_groups_title' => 'Transfer of tag groups and tags',
	'move_tags_groups_id' => "<acronym title=\"Group into which tags and tag groups will be transferred.\">Parent group</acronym>",
	'move_tags_groups_form_button_name' => 'Transfer',
	'move_success' => 'Tags have been transferred.',
	'merge_success' => 'Tags have been merged.',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'seo_title' => '<acronym title="Meta element title">Title</acronym>',
	'seo_description' => '<acronym title="Meta element description">Description</acronym>',
	'seo_keywords' => '<acronym title="Meta element keywords">Keywords</acronym>',
	'h1' => "Heading H1",
);
